You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/12 08:15:23 UTC

[45/64] [abbrv] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiAdapter.java b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiAdapter.java
index 3d73650..508e81e 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiAdapter.java
@@ -576,22 +576,22 @@ public abstract class IgniteSpiAdapter implements IgniteSpi, IgniteSpiManagement
         }
 
         /** {@inheritDoc} */
-        @Override public <K, V> V get(String cacheName, K key) throws GridException {
+        @Override public <K, V> V get(String cacheName, K key) throws IgniteCheckedException {
             return null;
         }
 
         /** {@inheritDoc} */
-        @Override public <K, V> V put(String cacheName, K key, V val, long ttl) throws GridException {
+        @Override public <K, V> V put(String cacheName, K key, V val, long ttl) throws IgniteCheckedException {
             return null;
         }
 
         /** {@inheritDoc} */
-        @Override public <K, V> V putIfAbsent(String cacheName, K key, V val, long ttl) throws GridException {
+        @Override public <K, V> V putIfAbsent(String cacheName, K key, V val, long ttl) throws IgniteCheckedException {
             return null;
         }
 
         /** {@inheritDoc} */
-        @Override public <K, V> V remove(String cacheName, K key) throws GridException {
+        @Override public <K, V> V remove(String cacheName, K key) throws IgniteCheckedException {
             return null;
         }
 
@@ -602,32 +602,32 @@ public abstract class IgniteSpiAdapter implements IgniteSpi, IgniteSpiManagement
 
         /** {@inheritDoc} */
         @Override public void writeToSwap(String spaceName, Object key, @Nullable Object val,
-            @Nullable ClassLoader ldr) throws GridException {
+            @Nullable ClassLoader ldr) throws IgniteCheckedException {
             /* No-op. */
         }
 
         /** {@inheritDoc} */
         @Override public <T> T readFromSwap(String spaceName, SwapKey key, @Nullable ClassLoader ldr)
-            throws GridException {
+            throws IgniteCheckedException {
             return null;
         }
 
         /** {@inheritDoc} */
         @Nullable @Override public <T> T readFromOffheap(String spaceName, int part, Object key, byte[] keyBytes,
-            @Nullable ClassLoader ldr) throws GridException {
+            @Nullable ClassLoader ldr) throws IgniteCheckedException {
             return null;
         }
 
         /** {@inheritDoc} */
         @Override public boolean removeFromOffheap(@Nullable String spaceName, int part, Object key,
-            @Nullable byte[] keyBytes) throws GridException {
+            @Nullable byte[] keyBytes) throws IgniteCheckedException {
             return false;
         }
 
         /** {@inheritDoc} */
         @Override public void writeToOffheap(@Nullable String spaceName, int part, Object key,
             @Nullable byte[] keyBytes, Object val, @Nullable byte[] valBytes, @Nullable ClassLoader ldr)
-            throws GridException {
+            throws IgniteCheckedException {
             // No-op.
         }
 
@@ -638,7 +638,7 @@ public abstract class IgniteSpiAdapter implements IgniteSpi, IgniteSpiManagement
 
         /** {@inheritDoc} */
         @Override public void removeFromSwap(String spaceName, Object key, @Nullable ClassLoader ldr)
-            throws GridException {
+            throws IgniteCheckedException {
             // No-op.
         }
 
@@ -709,18 +709,18 @@ public abstract class IgniteSpiAdapter implements IgniteSpi, IgniteSpiManagement
         }
 
         /** {@inheritDoc} */
-        @Override public Collection<GridSecuritySubject> authenticatedSubjects() throws GridException {
+        @Override public Collection<GridSecuritySubject> authenticatedSubjects() throws IgniteCheckedException {
             return Collections.emptyList();
         }
 
         /** {@inheritDoc} */
-        @Override public GridSecuritySubject authenticatedSubject(UUID subjId) throws GridException {
+        @Override public GridSecuritySubject authenticatedSubject(UUID subjId) throws IgniteCheckedException {
             return null;
         }
 
         /** {@inheritDoc} */
         @Nullable @Override public <T> T readValueFromOffheapAndSwap(@Nullable String spaceName, Object key,
-            @Nullable ClassLoader ldr) throws GridException {
+            @Nullable ClassLoader ldr) throws IgniteCheckedException {
             return null;
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
index 449e2dd..51fbf2b 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
@@ -9,12 +9,12 @@
 
 package org.apache.ignite.spi;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * Exception thrown by SPI implementations.
  */
-public class IgniteSpiException extends GridException {
+public class IgniteSpiException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/cache/CacheCheckpointSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/cache/CacheCheckpointSpi.java
index c3084e4..886b1ef 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/cache/CacheCheckpointSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/cache/CacheCheckpointSpi.java
@@ -176,7 +176,7 @@ public class CacheCheckpointSpi extends IgniteSpiAdapter implements CheckpointSp
         try {
             return getSpiContext().get(cacheName, key);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to load checkpoint data [key=" + key + ']', e);
         }
     }
@@ -196,7 +196,7 @@ public class CacheCheckpointSpi extends IgniteSpiAdapter implements CheckpointSp
             else
                 return getSpiContext().putIfAbsent(cacheName, key, state, timeout) == null;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to save checkpoint data [key=" + key +
                 ", stateSize=" + state.length + ", timeout=" + timeout + ']', e);
         }
@@ -209,7 +209,7 @@ public class CacheCheckpointSpi extends IgniteSpiAdapter implements CheckpointSp
         try {
             return getSpiContext().remove(cacheName, key) != null;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to remove checkpoint data [key=" + key + ']', e);
 
             return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
index efef65e..3c93370 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
@@ -259,7 +259,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                 try {
                     folder = U.resolveWorkDirectory(curDirPath, false);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     if (log.isDebugEnabled())
                         log.debug("Failed to resolve directory [path=" + curDirPath +
                             ", exception=" + e.getMessage() + ']');
@@ -302,7 +302,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                                 log.debug("Registered existing checkpoint from: " + file.getAbsolutePath());
                         }
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to unmarshal objects in checkpoint file (ignoring): " +
                             file.getAbsolutePath(), e);
                     }
@@ -363,7 +363,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                         null
                     : null;
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new IgniteSpiException("Failed to unmarshal objects in checkpoint file: " +
                     file.getAbsolutePath(), e);
             }
@@ -413,7 +413,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                     throw new IgniteSpiException("Failed to write checkpoint data into file: " +
                         file.getAbsolutePath(), e);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new IgniteSpiException("Failed to marshal checkpoint data into file: " +
                     file.getAbsolutePath(), e);
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
index 549b2ce..442caef 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
@@ -106,7 +106,7 @@ class SharedFsTimeoutTask extends IgniteSpiThread {
                         if (timeData.getLastAccessTime() != file.lastModified())
                             timeData.setExpireTime(SharedFsUtils.read(file, marshaller, log).getExpireTime());
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to marshal/unmarshal in checkpoint file: " + file.getAbsolutePath(), e);
 
                         continue;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/collision/jobstealing/JobStealingDisabled.java b/modules/core/src/main/java/org/apache/ignite/spi/collision/jobstealing/JobStealingDisabled.java
index bdfb8f0..10db8c5 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/collision/jobstealing/JobStealingDisabled.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/collision/jobstealing/JobStealingDisabled.java
@@ -20,7 +20,7 @@ import java.lang.annotation.*;
  * <pre name="code" class="java">
  * &#64;GridJobStealingDisabled
  * public class MyJob extends GridComputeJobAdapter&lt;Object&gt; {
- *     public Serializable execute() throws GridException {
+ *     public Serializable execute() throws IgniteCheckedException {
  *         // Job logic goes here.
  *         ...
  *     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/collision/priorityqueue/PriorityQueueCollisionSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/collision/priorityqueue/PriorityQueueCollisionSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/collision/priorityqueue/PriorityQueueCollisionSpi.java
index c20f1b4..8d5d616 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/collision/priorityqueue/PriorityQueueCollisionSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/collision/priorityqueue/PriorityQueueCollisionSpi.java
@@ -101,7 +101,7 @@ import java.util.*;
  *    private GridComputeTaskSession taskSes;
  *
  *    &#64;Override
- *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws GridException {
+ *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws IgniteCheckedException {
  *        ...
  *        // Set low task priority (note that attribute name is used by the SPI
  *        // and should not be changed).
@@ -127,7 +127,7 @@ import java.util.*;
  *    private GridComputeTaskSession taskSes;
  *
  *    &#64;Override
- *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws GridException {
+ *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws IgniteCheckedException {
  *        ...
  *        // Set high task priority (note that attribute name is used by the SPI
  *        // and should not be changed).

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
index 7f6d5c1..35aec0e 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
@@ -686,7 +686,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
         try {
             addrs = U.resolveLocalAddresses(locHost);
         }
-        catch (IOException | GridException e) {
+        catch (IOException | IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to resolve local host to set of external addresses: " + locHost, e);
         }
 
@@ -706,7 +706,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
             if (extAddrs != null)
                 locNodeAttrs.put(createSpiAttributeName(ATTR_EXT_ADDRS), extAddrs);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to resolve local host to addresses: " + locHost, e);
         }
 
@@ -1129,7 +1129,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
                 return node.id().equals(t.get1()) && (clientNodeId == null || t.get2());
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 if (log.isDebugEnabled())
                     log.debug("Failed to ping node [node=" + node + ", err=" + e.getMessage() + ']');
 
@@ -1148,7 +1148,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
      * @throws org.apache.ignite.spi.IgniteSpiException If an error occurs.
      */
     private IgniteBiTuple<UUID, Boolean> pingNode(InetSocketAddress addr, @Nullable UUID clientNodeId)
-        throws GridException {
+        throws IgniteCheckedException {
         assert addr != null;
 
         if (F.contains(locNodeAddrs, addr))
@@ -1194,7 +1194,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
                         return t;
                     }
-                    catch (IOException | GridException e) {
+                    catch (IOException | IgniteCheckedException e) {
                         if (errs == null)
                             errs = new ArrayList<>();
 
@@ -1270,7 +1270,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
                     locNode.setAttributes(attrs);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     throw new IgniteSpiException("Failed to authenticate local node (will shutdown local node).", e);
                 }
 
@@ -1406,7 +1406,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                 return false;
 
             boolean retry = false;
-            GridException errs = null;
+            IgniteCheckedException errs = null;
 
             for (InetSocketAddress addr : addrs) {
                 try {
@@ -1451,7 +1451,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                 }
                 catch (IgniteSpiException e) {
                     if (errs == null)
-                        errs = new GridException("Multiple connection attempts failed.");
+                        errs = new IgniteCheckedException("Multiple connection attempts failed.");
 
                     errs.addSuppressed(e);
 
@@ -1592,7 +1592,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
                 errs.add(e);
             }
-            catch (IOException | GridException e) {
+            catch (IOException | IgniteCheckedException e) {
                 if (log.isDebugEnabled())
                     log.error("Exception on direct send: " + e.getMessage(), e);
 
@@ -1655,7 +1655,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
             node.setAttributes(attrs);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to marshal node security credentials: " + node.id(), e);
         }
     }
@@ -1676,7 +1676,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
             return marsh.unmarshal(credBytes, null);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to unmarshal node security credentials: " + node.id(), e);
         }
     }
@@ -2342,7 +2342,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                                 try {
                                     res = pingNode(addr, null).get1() != null;
                                 }
-                                catch (GridException e) {
+                                catch (IgniteCheckedException e) {
                                     if (log.isDebugEnabled())
                                         log.debug("Failed to ping node [addr=" + addr +
                                             ", err=" + e.getMessage() + ']');
@@ -2728,7 +2728,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                                     success = true;
                                 }
                             }
-                            catch (IOException | GridException e) {
+                            catch (IOException | IgniteCheckedException e) {
                                 if (errs == null)
                                     errs = new ArrayList<>();
 
@@ -2849,7 +2849,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
                             break addr;
                         }
-                        catch (IOException | GridException e) {
+                        catch (IOException | IgniteCheckedException e) {
                             if (errs == null)
                                 errs = new ArrayList<>();
 
@@ -3132,7 +3132,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                         node.setAttributes(attrs);
                     }
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     LT.error(log, e, "Authentication failed [nodeId=" + node.id() + ", addrs=" +
                         U.addressesAsString(node) + ']');
 
@@ -3583,7 +3583,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                                 authFailed = false;
                         }
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to verify node permissions consistency (will drop the node): " + node, e);
                     }
                     finally {
@@ -3958,7 +3958,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                         if (log.isDebugEnabled())
                             log.debug("Sent verified node left message to leaving node: " + msg);
                     }
-                    catch (GridException | IOException e) {
+                    catch (IgniteCheckedException | IOException e) {
                         if (log.isDebugEnabled())
                             log.debug("Failed to send verified node left message to leaving node [msg=" + msg +
                                 ", err=" + e.getMessage() + ']');
@@ -4659,7 +4659,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
 
                     return;
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     if (log.isDebugEnabled())
                         U.error(log, "Caught exception on handshake [err=" + e +", sock=" + sock + ']', e);
 
@@ -4868,7 +4868,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                         if (!client)
                             writeToSocket(sock, RES_OK);
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         if (log.isDebugEnabled())
                             U.error(log, "Caught exception on message read [sock=" + sock +
                                 ", locNodeId=" + locNodeId + ", rmtNodeId=" + nodeId + ']', e);
@@ -5123,7 +5123,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter implements TcpDiscov
                     clearNodeAddedMessage(msg);
                 }
             }
-            catch (GridException | IOException e) {
+            catch (IgniteCheckedException | IOException e) {
                 if (log.isDebugEnabled())
                     U.error(log, "Client connection failed [sock=" + sock + ", locNodeId=" + locNodeId +
                         ", rmtNodeId=" + nodeId + ", msg=" + msg + ']', e);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
index d47f9ac..110a3bd 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
@@ -129,7 +129,7 @@ public class TcpDiscoverySharedFsIpFinder extends TcpDiscoveryIpFinderAdapter {
                     try {
                         tmp = U.resolveWorkDirectory(path, false);
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         throw new IgniteSpiException("Failed to resolve directory [path=" + path +
                             ", exception=" + e.getMessage() + ']');
                     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/vm/TcpDiscoveryVmIpFinder.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/vm/TcpDiscoveryVmIpFinder.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/vm/TcpDiscoveryVmIpFinder.java
index a6e9c0a..5763a88 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/vm/TcpDiscoveryVmIpFinder.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/vm/TcpDiscoveryVmIpFinder.java
@@ -64,7 +64,7 @@ public class TcpDiscoveryVmIpFinder extends TcpDiscoveryIpFinderAdapter {
                             addrsList.addAll(address(s));
                         }
                         catch (IgniteSpiException e) {
-                            throw new GridRuntimeException(e);
+                            throw new IgniteException(e);
                         }
                     }
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/failover/FailoverContext.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
index 7a8e591..46a071b 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
@@ -219,7 +219,7 @@ public class AlwaysFailoverSpi extends IgniteSpiAdapter implements FailoverSpi,
 
             return node;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to get next balanced node for failover: " + ctx, e);
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
index 45c5f3d..8fea012 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
@@ -324,7 +324,7 @@ public class JobStealingFailoverSpi extends IgniteSpiAdapter implements Failover
 
             return thief;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to get next balanced node for failover: " + ctx, e);
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/indexing/GridIndexingQueryFilter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/indexing/GridIndexingQueryFilter.java b/modules/core/src/main/java/org/apache/ignite/spi/indexing/GridIndexingQueryFilter.java
index f91f414..a6a1002 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/indexing/GridIndexingQueryFilter.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/indexing/GridIndexingQueryFilter.java
@@ -9,6 +9,7 @@
 
 package org.apache.ignite.spi.indexing;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/LoadBalancingSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
index da2477c..f9756b2 100644
--- a/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
@@ -9,6 +9,7 @@
 
 package org.apache.ignite.scheduler;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
 
@@ -83,9 +84,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @param cnt Array length.
      * @param start Start timestamp.
      * @return Array of the next execution times in milliseconds.
      * @throws GridException Thrown in case of any errors.
      */
-    public long[] nextExecutionTimes(int cnt, long start) throws GridException;
+    public long[] nextExecutionTimes(int cnt, long start) throws IgniteCheckedException;
 
     /**
      * Gets total count of executions this task has already completed.
@@ -105,9 +106,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * Gets next execution time of scheduled task.
      *
      * @return Next execution time in milliseconds.
      * @throws GridException Thrown in case of any errors.
      */
-    public long nextExecutionTime() throws GridException;
+    public long nextExecutionTime() throws IgniteCheckedException;
 
     /**
      * Gets result of the last execution of scheduled task, or
@@ -116,9 +117,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      *
      * @return Result of the last execution, or {@code null} if
      *      there isn't one yet.
      * @throws GridException If last execution resulted in exception.
      */
-    public R last() throws GridException;
+    public R last() throws IgniteCheckedException;
 
     /**
      * Waits for the completion of the next scheduled execution and returns its result.
@@ -126,9 +127,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @return Result of the next execution.
      * @throws CancellationException {@inheritDoc}
      * @throws GridInterruptedException {@inheritDoc}
-     * @throws GridException {@inheritDoc}
+     * @throws IgniteCheckedException {@inheritDoc}
      */
-    @Override public R get() throws GridException;
+    @Override public R get() throws IgniteCheckedException;
 
     /**
      * Waits for the completion of the next scheduled execution for
@@ -140,9 +141,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @throws CancellationException {@inheritDoc}
      * @throws GridInterruptedException {@inheritDoc}
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException {@inheritDoc}
-     * @throws GridException {@inheritDoc}
+     * @throws IgniteCheckedException {@inheritDoc}
      */
-    @Override public R get(long timeout) throws GridException;
+    @Override public R get(long timeout) throws IgniteCheckedException;
 
     /**
      * Waits for the completion of the next scheduled execution for
@@ -154,7 +155,7 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @throws CancellationException {@inheritDoc}
      * @throws GridInterruptedException {@inheritDoc}
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException {@inheritDoc}
-     * @throws GridException {@inheritDoc}
+     * @throws IgniteCheckedException {@inheritDoc}
      */
-    @Override public R get(long timeout, TimeUnit unit) throws GridException;
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiAdapter.java
----------------------------------------------------------------------
@@ -83,9 +84,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @param start Start timestamp.
      * @return Array of the next execution times in milliseconds.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -105,9 +106,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      *
      * @return Next execution time in milliseconds.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -116,9 +117,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @return Result of the last execution, or {@code null} if
      *      there isn't one yet.
-     * @throws GridException If last execution resulted in exception.
+     * @throws IgniteCheckedException If last execution resulted in exception.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
index 802b901..901b232 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.spi;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 import java.io.*;
 import java.util.*;
@@ -25,7 +25,7 @@ public interface IgniteSpiCloseableIterator<T> extends Iterator<T>, AutoCloseabl
      * The method is invoked automatically on objects managed by the
      * {@code try-with-resources} statement.
      *
      * @throws GridException In case of error.
      */
-    @Override public void close() throws GridException;
+    @Override public void close() throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiContext.java
----------------------------------------------------------------------
@@ -25,7 +25,7 @@ public interface IgniteSpiCloseableIterator<T> extends Iterator<T>, AutoCloseabl
      * {@code try-with-resources} statement.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiContext.java b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiContext.java
index 5d5dfb7..69ba6fd 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiContext.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiContext.java
@@ -9,13 +9,13 @@
 
 package org.apache.ignite.spi;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.events.*;
-import org.gridgain.grid.*;
-import org.gridgain.grid.kernal.managers.communication.*;
-import org.gridgain.grid.kernal.managers.eventstorage.*;
 import org.apache.ignite.plugin.security.*;
 import org.apache.ignite.spi.swapspace.*;
+import org.gridgain.grid.kernal.managers.communication.*;
+import org.gridgain.grid.kernal.managers.eventstorage.*;
 import org.gridgain.grid.util.direct.*;
 import org.jetbrains.annotations.*;
 
@@ -189,9 +189,9 @@ public interface IgniteSpiContext {
      * @param cacheName Cache name.
      * @param key Object key.
      * @return Cached object.
      * @throws GridException Thrown if any exception occurs.
      */
-    @Nullable public <K, V> V get(String cacheName, K key) throws GridException;
+    @Nullable public <K, V> V get(String cacheName, K key) throws IgniteCheckedException;
 
     /**
      * Puts object in cache.
@@ -203,9 +203,9 @@ public interface IgniteSpiContext {
      * @param <K> Key type.
      * @param <V> Value type.
      * @return Previous value associated with specified key, possibly {@code null}.
      * @throws GridException Thrown if any exception occurs.
      */
-    @Nullable public <K, V> V put(String cacheName, K key, V val, long ttl) throws GridException;
+    @Nullable public <K, V> V put(String cacheName, K key, V val, long ttl) throws IgniteCheckedException;
 
     /**
      * Puts object into cache if there was no previous object associated with
@@ -218,9 +218,9 @@ public interface IgniteSpiContext {
      * @param <K> Cache key type.
      * @param <V> Cache value type.
      * @return Either existing value or {@code null} if there was no value for given key.
      * @throws GridException If put failed.
      */
-    @Nullable public <K, V> V putIfAbsent(String cacheName, K key, V val, long ttl) throws GridException;
+    @Nullable public <K, V> V putIfAbsent(String cacheName, K key, V val, long ttl) throws IgniteCheckedException;
 
     /**
      * Removes object from cache.
@@ -230,9 +230,9 @@ public interface IgniteSpiContext {
      * @param <K> Key type.
      * @param <V> Value type.
      * @return Previous value associated with specified key, possibly {@code null}.
      * @throws GridException Thrown if any exception occurs.
      */
-    @Nullable public <K, V> V remove(String cacheName, K key) throws GridException;
+    @Nullable public <K, V> V remove(String cacheName, K key) throws IgniteCheckedException;
 
     /**
      * Returns {@code true} if this cache contains a mapping for the specified key.
@@ -251,10 +251,10 @@ public interface IgniteSpiContext {
      * @param key Key.
      * @param val Value.
      * @param ldr Class loader (optional).
      * @throws GridException If any exception occurs.
      */
     public void writeToSwap(String spaceName, Object key, @Nullable Object val, @Nullable ClassLoader ldr)
-        throws GridException;
+        throws IgniteCheckedException;
 
     /**
      * Reads object from swap.
@@ -263,10 +263,10 @@ public interface IgniteSpiContext {
      * @param key Key.
      * @param ldr Class loader (optional).
      * @return Swapped value.
      * @throws GridException If any exception occurs.
      */
     @Nullable public <T> T readFromSwap(String spaceName, SwapKey key, @Nullable ClassLoader ldr)
-        throws GridException;
+        throws IgniteCheckedException;
 
 
     /**
@@ -278,10 +278,10 @@ public interface IgniteSpiContext {
      * @param keyBytes Key bytes.
      * @param ldr Class loader for unmarshalling.
      * @return Value.
      * @throws GridException If failed.
      */
     @Nullable public <T> T readFromOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes,
-        @Nullable ClassLoader ldr) throws GridException;
+        @Nullable ClassLoader ldr) throws IgniteCheckedException;
 
     /**
      * Writes data to off-heap memory.
@@ -293,10 +293,10 @@ public interface IgniteSpiContext {
      * @param val Value.
      * @param valBytes Optional value bytes.
      * @param ldr Class loader.
      * @throws GridException If failed.
      */
     public void writeToOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes, Object val,
-        @Nullable byte[] valBytes, @Nullable ClassLoader ldr) throws GridException;
+        @Nullable byte[] valBytes, @Nullable ClassLoader ldr) throws IgniteCheckedException;
 
     /**
      * Removes data from off-heap memory.
@@ -306,10 +306,10 @@ public interface IgniteSpiContext {
      * @param key Key.
      * @param keyBytes Optional key bytes.
      * @return {@code true} If succeeded.
      * @throws GridException If failed.
      */
     public boolean removeFromOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes)
-        throws GridException;
+        throws IgniteCheckedException;
 
     /**
      * Calculates partition number for given key.
@@ -326,9 +326,9 @@ public interface IgniteSpiContext {
      * @param spaceName Swap space name.
      * @param key Key.
      * @param ldr Class loader (optional).
      * @throws GridException If any exception occurs.
      */
-    public void removeFromSwap(String spaceName, Object key, @Nullable ClassLoader ldr) throws GridException;
+    public void removeFromSwap(String spaceName, Object key, @Nullable ClassLoader ldr) throws IgniteCheckedException;
 
     /**
      * Validates that new node can join grid topology, this method is called on coordinator
@@ -363,18 +363,18 @@ public interface IgniteSpiContext {
      * Gets collection of authenticated subjects together with their permissions.
      *
      * @return Collection of authenticated subjects.
      * @throws GridException If any exception occurs.
      */
-    public Collection<GridSecuritySubject> authenticatedSubjects() throws GridException;
+    public Collection<GridSecuritySubject> authenticatedSubjects() throws IgniteCheckedException;
 
     /**
      * Gets security subject based on subject ID.
      *
      * @param subjId Subject ID.
      * @return Authorized security subject.
      * @throws GridException If any exception occurs.
      */
-    public GridSecuritySubject authenticatedSubject(UUID subjId) throws GridException;
+    public GridSecuritySubject authenticatedSubject(UUID subjId) throws IgniteCheckedException;
 
     /**
      * Reads swapped cache value from off-heap and swap.
@@ -383,10 +383,10 @@ public interface IgniteSpiContext {
      * @param key Key.
      * @param ldr Class loader for unmarshalling.
      * @return Value.
      * @throws GridException If any exception occurs.
      */
     @Nullable public <T> T readValueFromOffheapAndSwap(@Nullable String spaceName, Object key,
-        @Nullable ClassLoader ldr) throws GridException;
+        @Nullable ClassLoader ldr) throws IgniteCheckedException;
 
     /**
      * @return Message factory.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
----------------------------------------------------------------------
@@ -189,9 +189,9 @@ public interface IgniteSpiContext {
      * @param key Object key.
      * @return Cached object.
-     * @throws GridException Thrown if any exception occurs.
+     * @throws IgniteCheckedException Thrown if any exception occurs.
      */
@@ -203,9 +203,9 @@ public interface IgniteSpiContext {
      * @param <V> Value type.
      * @return Previous value associated with specified key, possibly {@code null}.
-     * @throws GridException Thrown if any exception occurs.
+     * @throws IgniteCheckedException Thrown if any exception occurs.
      */
@@ -218,9 +218,9 @@ public interface IgniteSpiContext {
      * @param <V> Cache value type.
      * @return Either existing value or {@code null} if there was no value for given key.
-     * @throws GridException If put failed.
+     * @throws IgniteCheckedException If put failed.
      */
@@ -230,9 +230,9 @@ public interface IgniteSpiContext {
      * @param <V> Value type.
      * @return Previous value associated with specified key, possibly {@code null}.
-     * @throws GridException Thrown if any exception occurs.
+     * @throws IgniteCheckedException Thrown if any exception occurs.
      */
@@ -251,10 +251,10 @@ public interface IgniteSpiContext {
      * @param val Value.
      * @param ldr Class loader (optional).
-     * @throws GridException If any exception occurs.
+     * @throws IgniteCheckedException If any exception occurs.
      */
     public void writeToSwap(String spaceName, Object key, @Nullable Object val, @Nullable ClassLoader ldr)
@@ -263,10 +263,10 @@ public interface IgniteSpiContext {
      * @param ldr Class loader (optional).
      * @return Swapped value.
-     * @throws GridException If any exception occurs.
+     * @throws IgniteCheckedException If any exception occurs.
      */
     @Nullable public <T> T readFromSwap(String spaceName, SwapKey key, @Nullable ClassLoader ldr)
@@ -278,10 +278,10 @@ public interface IgniteSpiContext {
      * @param ldr Class loader for unmarshalling.
      * @return Value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @Nullable public <T> T readFromOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes,
@@ -293,10 +293,10 @@ public interface IgniteSpiContext {
      * @param valBytes Optional value bytes.
      * @param ldr Class loader.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     public void writeToOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes, Object val,
@@ -306,10 +306,10 @@ public interface IgniteSpiContext {
      * @param keyBytes Optional key bytes.
      * @return {@code true} If succeeded.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     public boolean removeFromOffheap(@Nullable String spaceName, int part, Object key, @Nullable byte[] keyBytes)
@@ -326,9 +326,9 @@ public interface IgniteSpiContext {
      * @param key Key.
      * @param ldr Class loader (optional).
-     * @throws GridException If any exception occurs.
+     * @throws IgniteCheckedException If any exception occurs.
      */
@@ -363,18 +363,18 @@ public interface IgniteSpiContext {
      *
      * @return Collection of authenticated subjects.
-     * @throws GridException If any exception occurs.
+     * @throws IgniteCheckedException If any exception occurs.
      */
@@ -363,18 +363,18 @@ public interface IgniteSpiContext {
      * @param subjId Subject ID.
      * @return Authorized security subject.
-     * @throws GridException If any exception occurs.
+     * @throws IgniteCheckedException If any exception occurs.
      */
@@ -383,10 +383,10 @@ public interface IgniteSpiContext {
      * @param ldr Class loader for unmarshalling.
      * @return Value.
-     * @throws GridException If any exception occurs.
+     * @throws IgniteCheckedException If any exception occurs.
      */
     @Nullable public <T> T readValueFromOffheapAndSwap(@Nullable String spaceName, Object key,
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java b/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
index e8c2b84..d535152 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
@@ -9,7 +9,7 @@
 
 package org.apache.ignite.spi.authentication;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.apache.ignite.plugin.security.*;
 
 import java.util.*;
@@ -27,7 +27,7 @@ public interface AuthenticationAclProvider {
      * Gets per-user access control map.
      *
      * @return Per-user access control map.
      * @throws GridException If failed.
      */
-    public Map<GridSecurityCredentials, GridSecurityPermissionSet> acl() throws GridException;
+    public Map<GridSecurityCredentials, GridSecurityPermissionSet> acl() throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/cache/CacheCheckpointSpi.java
----------------------------------------------------------------------
@@ -27,7 +27,7 @@ public interface AuthenticationAclProvider {
      *
      * @return Per-user access control map.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
index 6b62553..f819321 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
@@ -35,12 +35,12 @@ final class SharedFsUtils {
      * @param m Grid marshaller.
      * @param log Messages logger.
      * @return Checkpoint data object read from given file.
      * @throws GridException Thrown if data could not be converted
      *    to {@link SharedFsCheckpointData} object.
      * @throws IOException Thrown if file read error occurred.
      */
     static SharedFsCheckpointData read(File file, IgniteMarshaller m, IgniteLogger log)
-        throws IOException, GridException {
+        throws IOException, IgniteCheckedException {
         assert file != null;
         assert m != null;
         assert log != null;
@@ -63,11 +63,11 @@ final class SharedFsUtils {
      * @param data Checkpoint data.
      * @param m Grid marshaller.
      * @param log Messages logger.
      * @throws GridException Thrown if data could not be marshalled.
      * @throws IOException Thrown if file write operation failed.
      */
     static void write(File file, SharedFsCheckpointData data, IgniteMarshaller m, IgniteLogger log)
-        throws IOException, GridException {
+        throws IOException, IgniteCheckedException {
         assert file != null;
         assert m != null;
         assert data != null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/collision/jobstealing/JobStealingDisabled.java
----------------------------------------------------------------------
@@ -35,12 +35,12 @@ final class SharedFsUtils {
      * @param log Messages logger.
      * @return Checkpoint data object read from given file.
-     * @throws GridException Thrown if data could not be converted
+     * @throws IgniteCheckedException Thrown if data could not be converted
      *    to {@link SharedFsCheckpointData} object.
      * @throws IOException Thrown if file read error occurred.
@@ -63,11 +63,11 @@ final class SharedFsUtils {
      * @param m Grid marshaller.
      * @param log Messages logger.
-     * @throws GridException Thrown if data could not be marshalled.
+     * @throws IgniteCheckedException Thrown if data could not be marshalled.
      * @throws IOException Thrown if file write operation failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
index a80421e..0b3330a 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
@@ -1075,7 +1075,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
         try {
             shmemSrv = resetShmemServer();
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.warn(log, "Failed to start shared memory communication server.", e);
         }
 
@@ -1084,7 +1084,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
             // local node was bound to.
             nioSrvr = resetNioServer();
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to initialize TCP server: " + locHost, e);
         }
 
@@ -1102,7 +1102,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                 createSpiAttributeName(ATTR_SHMEM_PORT), boundTcpShmemPort >= 0 ? boundTcpShmemPort : null,
                 createSpiAttributeName(ATTR_EXT_ADDRS), extAddrs);
         }
-        catch (IOException | GridException e) {
+        catch (IOException | IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to resolve local host to addresses: " + locHost, e);
         }
     }
@@ -1214,13 +1214,13 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * Recreates tpcSrvr socket instance.
      *
      * @return Server instance.
      * @throws GridException Thrown if it's not possible to create server.
      */
-    private GridNioServer<GridTcpCommunicationMessageAdapter> resetNioServer() throws GridException {
+    private GridNioServer<GridTcpCommunicationMessageAdapter> resetNioServer() throws IgniteCheckedException {
         if (boundTcpPort >= 0)
-            throw new GridException("Tcp NIO server was already created on port " + boundTcpPort);
+            throw new IgniteCheckedException("Tcp NIO server was already created on port " + boundTcpPort);
 
-        GridException lastEx = null;
+        IgniteCheckedException lastEx = null;
 
         // If configured TCP port is busy, find first available in range.
         for (int port = locPort; port < locPort + locPortRange; port++) {
@@ -1257,7 +1257,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
 
                 return srvr;
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 lastEx = e;
 
                 if (log.isDebugEnabled())
@@ -1267,23 +1267,23 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
         }
 
         // If free port wasn't found.
-        throw new GridException("Failed to bind to any port within range [startPort=" + locPort +
+        throw new IgniteCheckedException("Failed to bind to any port within range [startPort=" + locPort +
             ", portRange=" + locPortRange + ", locHost=" + locHost + ']', lastEx);
     }
 
     /**
      * Creates new shared memory communication server.
      * @return Server.
      * @throws GridException If failed.
      */
-    @Nullable private GridIpcSharedMemoryServerEndpoint resetShmemServer() throws GridException {
+    @Nullable private GridIpcSharedMemoryServerEndpoint resetShmemServer() throws IgniteCheckedException {
         if (boundTcpShmemPort >= 0)
-            throw new GridException("Shared memory server was already created on port " + boundTcpShmemPort);
+            throw new IgniteCheckedException("Shared memory server was already created on port " + boundTcpShmemPort);
 
         if (shmemPort == -1 || U.isWindows())
             return null;
 
-        GridException lastEx = null;
+        IgniteCheckedException lastEx = null;
 
         // If configured TCP port is busy, find first available in range.
         for (int port = shmemPort; port < shmemPort + locPortRange; port++) {
@@ -1305,7 +1305,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
 
                 return srv;
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 lastEx = e;
 
                 if (log.isDebugEnabled())
@@ -1315,7 +1315,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
         }
 
         // If free port wasn't found.
-        throw new GridException("Failed to bind shared memory communication to any port within range [startPort=" +
+        throw new IgniteCheckedException("Failed to bind shared memory communication to any port within range [startPort=" +
             locPort + ", portRange=" + locPortRange + ", locHost=" + locHost + ']', lastEx);
     }
 
@@ -1443,7 +1443,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
 
                 sentMsgsCnt.increment();
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new IgniteSpiException("Failed to send message to remote node: " + node, e);
             }
             finally {
@@ -1458,9 +1458,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      *
      * @param node Node to which client should be open.
      * @return The existing or just created client.
      * @throws GridException Thrown if any exception occurs.
      */
-    private GridCommunicationClient reserveClient(ClusterNode node) throws GridException {
+    private GridCommunicationClient reserveClient(ClusterNode node) throws IgniteCheckedException {
         assert node != null;
 
         UUID nodeId = node.id();
@@ -1506,9 +1506,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
     /**
      * @param node Node to create client for.
      * @return Client.
      * @throws GridException If failed.
      */
-    @Nullable protected GridCommunicationClient createNioClient(ClusterNode node) throws GridException {
+    @Nullable protected GridCommunicationClient createNioClient(ClusterNode node) throws IgniteCheckedException {
         assert node != null;
 
         Integer shmemPort = node.attribute(createSpiAttributeName(ATTR_SHMEM_PORT));
@@ -1516,7 +1516,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
         ClusterNode locNode = getSpiContext().localNode();
 
         if (locNode == null)
-            throw new GridException("Failed to create NIO client (local node is stopping)");
+            throw new IgniteCheckedException("Failed to create NIO client (local node is stopping)");
 
         // If remote node has shared memory server enabled and has the same set of MACs
         // then we are likely to run on the same host and shared memory communication could be tried.
@@ -1524,7 +1524,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
             try {
                 return createShmemClient(node, shmemPort);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 if (e.hasCause(GridIpcOutOfSystemResourcesException.class))
                     // Has cause or is itself the GridIpcOutOfSystemResourcesException.
                     LT.warn(log, null, OUT_OF_RESOURCES_TCP_MSG);
@@ -1543,9 +1543,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param node Node.
      * @param port Port.
      * @return Client.
      * @throws GridException If failed.
      */
-    @Nullable protected GridCommunicationClient createShmemClient(ClusterNode node, Integer port) throws GridException {
+    @Nullable protected GridCommunicationClient createShmemClient(ClusterNode node, Integer port) throws IgniteCheckedException {
         int attempt = 1;
 
         int connectAttempts = 1;
@@ -1558,7 +1558,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
             try {
                 client = new GridShmemCommunicationClient(metricsLsnr, port, connTimeout, log, msgWriter);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 // Reconnect for the second time, if connection is not established.
                 if (connectAttempts < 2 && X.hasCause(e, ConnectException.class)) {
                     connectAttempts++;
@@ -1596,7 +1596,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                     continue;
                 }
             }
-            catch (GridException | RuntimeException | Error e) {
+            catch (IgniteCheckedException | RuntimeException | Error e) {
                 if (log.isDebugEnabled())
                     log.debug(
                         "Caught exception (will close client) [err=" + e.getMessage() + ", client=" + client + ']');
@@ -1615,9 +1615,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      *
      * @param node Remote node.
      * @return Client.
      * @throws GridException If failed.
      */
-    protected GridCommunicationClient createTcpClient(ClusterNode node) throws GridException {
+    protected GridCommunicationClient createTcpClient(ClusterNode node) throws IgniteCheckedException {
         Collection<String> rmtAddrs0 = node.attribute(createSpiAttributeName(ATTR_ADDRS));
         Collection<String> rmtHostNames0 = node.attribute(createSpiAttributeName(ATTR_HOST_NAMES));
         Integer boundPort = node.attribute(createSpiAttributeName(ATTR_PORT));
@@ -1627,7 +1627,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
         boolean isExtAddrsExist = !F.isEmpty(extAddrs);
 
         if (!isRmtAddrsExist && !isExtAddrsExist)
-            throw new GridException("Failed to send message to the destination node. Node doesn't have any " +
+            throw new IgniteCheckedException("Failed to send message to the destination node. Node doesn't have any " +
                 "TCP communication addresses or mapped external addresses. Check configuration and make sure " +
                 "that you use the same communication SPI on all nodes. Remote node id: " + node.id());
 
@@ -1650,7 +1650,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
 
         boolean conn = false;
         GridCommunicationClient client = null;
-        GridException errs = null;
+        IgniteCheckedException errs = null;
 
         int connectAttempts = 1;
 
@@ -1735,12 +1735,12 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                                 ", err=" + e.getMessage() + ", addr=" + addr + ']');
 
                         if (errs == null)
-                            errs = new GridException("Failed to connect to node (is node still alive?). " +
+                            errs = new IgniteCheckedException("Failed to connect to node (is node still alive?). " +
                                 "Make sure that each GridComputeTask and GridCacheTransaction has a timeout set " +
                                 "in order to prevent parties from waiting forever in case of network issues " +
                                 "[nodeId=" + node.id() + ", addrs=" + addrs + ']');
 
-                        errs.addSuppressed(new GridException("Failed to connect to address: " + addr, e));
+                        errs.addSuppressed(new IgniteCheckedException("Failed to connect to address: " + addr, e));
 
                         break;
                     }
@@ -1767,12 +1767,12 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                             "configuration property) [addr=" + addr + ']');
 
                     if (errs == null)
-                        errs = new GridException("Failed to connect to node (is node still alive?). " +
+                        errs = new IgniteCheckedException("Failed to connect to node (is node still alive?). " +
                             "Make sure that each GridComputeTask and GridCacheTransaction has a timeout set " +
                             "in order to prevent parties from waiting forever in case of network issues " +
                             "[nodeId=" + node.id() + ", addrs=" + addrs + ']');
 
-                    errs.addSuppressed(new GridException("Failed to connect to address: " + addr, e));
+                    errs.addSuppressed(new IgniteCheckedException("Failed to connect to address: " + addr, e));
 
                     // Reconnect for the second time, if connection is not established.
                     if (connectAttempts < 2 &&
@@ -1814,10 +1814,10 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param client Client.
      * @param rmtNodeId Remote node.
      * @param timeout Timeout for handshake.
      * @throws GridException If handshake failed or wasn't completed withing timeout.
      */
     @SuppressWarnings("ThrowFromFinallyBlock")
-    private <T> void safeHandshake(T client, UUID rmtNodeId, long timeout) throws GridException {
+    private <T> void safeHandshake(T client, UUID rmtNodeId, long timeout) throws IgniteCheckedException {
         HandshakeTimeoutObject<T> obj = new HandshakeTimeoutObject<>(client, U.currentTimeMillis() + timeout);
 
         sockTimeoutWorker.addTimeoutObject(obj);
@@ -1837,7 +1837,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                         int read = ch.read(buf);
 
                         if (read == -1)
-                            throw new GridException("Failed to read remote node ID (connection closed).");
+                            throw new IgniteCheckedException("Failed to read remote node ID (connection closed).");
 
                         i += read;
                     }
@@ -1845,7 +1845,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                     UUID rmtNodeId0 = U.bytesToUuid(buf.array(), 1);
 
                     if (!rmtNodeId.equals(rmtNodeId0))
-                        throw new GridException("Remote node ID is not as expected [expected=" + rmtNodeId +
+                        throw new IgniteCheckedException("Remote node ID is not as expected [expected=" + rmtNodeId +
                             ", rcvd=" + rmtNodeId0 + ']');
                     else if (log.isDebugEnabled())
                         log.debug("Received remote node ID: " + rmtNodeId0);
@@ -1859,7 +1859,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                     if (log.isDebugEnabled())
                         log.debug("Failed to read from channel: " + e);
 
-                    throw new GridException("Failed to read from channel.", e);
+                    throw new IgniteCheckedException("Failed to read from channel.", e);
                 }
                 finally {
                     if (!success)
@@ -1902,7 +1902,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
     }
 
     /** Internal exception class for proper timeout handling. */
-    private static class HandshakeTimeoutException extends GridException {
+    private static class HandshakeTimeoutException extends IgniteCheckedException {
         /** */
         private static final long serialVersionUID = 0L;
 
@@ -1942,7 +1942,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                     new IgniteThread(e).start();
                 }
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 if (!isCancelled())
                     U.error(log, "Shmem server failed.", e);
             }
@@ -2305,7 +2305,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
 
         /** {@inheritDoc} */
         @SuppressWarnings("ThrowFromFinallyBlock")
-        @Override public void applyx(InputStream in, OutputStream out) throws GridException {
+        @Override public void applyx(InputStream in, OutputStream out) throws IgniteCheckedException {
             try {
                 // Handshake.
                 byte[] b = new byte[17];
@@ -2316,7 +2316,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                     int cnt = in.read(b, n, 17 - n);
 
                     if (cnt < 0)
-                        throw new GridException("Failed to get remote node ID (end of stream reached)");
+                        throw new IgniteCheckedException("Failed to get remote node ID (end of stream reached)");
 
                     n += cnt;
                 }
@@ -2325,17 +2325,17 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                 UUID id = U.bytesToUuid(b, 1);
 
                 if (!rmtNodeId.equals(id))
-                    throw new GridException("Remote node ID is not as expected [expected=" + rmtNodeId +
+                    throw new IgniteCheckedException("Remote node ID is not as expected [expected=" + rmtNodeId +
                         ", rcvd=" + id + ']');
                 else if (log.isDebugEnabled())
                     log.debug("Received remote node ID: " + id);
             }
             catch (SocketTimeoutException e) {
-                throw new GridException("Failed to perform handshake due to timeout (consider increasing " +
+                throw new IgniteCheckedException("Failed to perform handshake due to timeout (consider increasing " +
                     "'connectionTimeout' configuration property).", e);
             }
             catch (IOException e) {
-                throw new GridException("Failed to perform handshake.", e);
+                throw new IgniteCheckedException("Failed to perform handshake.", e);
             }
 
             try {
@@ -2349,7 +2349,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
                     log.debug("Sent local node ID [locNodeId=" + locNodeId + ", rmtNodeId=" + rmtNodeId + ']');
             }
             catch (IOException e) {
-                throw new GridException("Failed to perform handshake.", e);
+                throw new IgniteCheckedException("Failed to perform handshake.", e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
----------------------------------------------------------------------
@@ -1214,13 +1214,13 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      *
      * @return Server instance.
-     * @throws GridException Thrown if it's not possible to create server.
+     * @throws IgniteCheckedException Thrown if it's not possible to create server.
      */
@@ -1267,23 +1267,23 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * Creates new shared memory communication server.
      * @return Server.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -1458,9 +1458,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param node Node to which client should be open.
      * @return The existing or just created client.
-     * @throws GridException Thrown if any exception occurs.
+     * @throws IgniteCheckedException Thrown if any exception occurs.
      */
@@ -1506,9 +1506,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param node Node to create client for.
      * @return Client.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -1543,9 +1543,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param port Port.
      * @return Client.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -1615,9 +1615,9 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param node Remote node.
      * @return Client.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -1814,10 +1814,10 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter
      * @param rmtNodeId Remote node.
      * @param timeout Timeout for handshake.
-     * @throws GridException If handshake failed or wasn't completed withing timeout.
+     * @throws IgniteCheckedException If handshake failed or wasn't completed withing timeout.
      */
     @SuppressWarnings("ThrowFromFinallyBlock")
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
index 456d6a3..3d3368e 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
@@ -9,10 +9,10 @@
 
 package org.apache.ignite.spi.discovery;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.*;
-import org.gridgain.grid.kernal.managers.security.*;
 import org.apache.ignite.plugin.security.*;
+import org.gridgain.grid.kernal.managers.security.*;
 
 /**
  * Node authenticator.
@@ -24,10 +24,10 @@ public interface DiscoverySpiNodeAuthenticator {
      * @param node Node to authenticate.
      * @param cred Security credentials.
      * @return Security context if authentication succeeded or {@code null} if authentication failed.
      * @throws GridException If authentication process failed
      *      (invalid credentials should not lead to this exception).
      */
-    public GridSecurityContext authenticateNode(ClusterNode node, GridSecurityCredentials cred) throws GridException;
+    public GridSecurityContext authenticateNode(ClusterNode node, GridSecurityCredentials cred) throws IgniteCheckedException;
 
     /**
      * Gets global node authentication flag.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
----------------------------------------------------------------------
@@ -24,10 +24,10 @@ public interface DiscoverySpiNodeAuthenticator {
      * @param cred Security credentials.
      * @return Security context if authentication succeeded or {@code null} if authentication failed.
-     * @throws GridException If authentication process failed
+     * @throws IgniteCheckedException If authentication process failed
      *      (invalid credentials should not lead to this exception).
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
index b474852..bf1b783 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
@@ -9,15 +9,16 @@
 
 package org.apache.ignite.spi.discovery.tcp;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.discovery.*;
 import org.apache.ignite.spi.discovery.tcp.internal.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.multicast.*;
 import org.apache.ignite.spi.discovery.tcp.messages.*;
+import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jdk8.backport.*;
@@ -240,7 +241,7 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
         try {
             addrs = U.resolveLocalAddresses(locHost);
         }
-        catch (IOException | GridException e) {
+        catch (IOException | IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to resolve local host to set of external addresses: " + locHost, e);
         }
 
@@ -297,7 +298,7 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
                             sock0 + ']');
                 }
             }
-            catch (IOException | GridException e) {
+            catch (IOException | IgniteCheckedException e) {
                 if (log.isDebugEnabled())
                     U.error(log, "Failed to send node left message (will stop anyway) [sock=" + sock0 + ']', e);
             }
@@ -492,7 +493,7 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
 
                         return false;
                     }
-                    catch (IOException | GridException e) {
+                    catch (IOException | IgniteCheckedException e) {
                         if (log.isDebugEnabled())
                             U.error(log, "Failed to establish connection with address: " + addr, e);
 
@@ -522,9 +523,9 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
      * @param addr Address.
      * @return Remote node ID.
      * @throws IOException In case of I/O error.
      * @throws GridException In case of other error.
      */
-    private IgniteBiTuple<Socket, UUID> initConnection(InetSocketAddress addr) throws IOException, GridException {
+    private IgniteBiTuple<Socket, UUID> initConnection(InetSocketAddress addr) throws IOException, IgniteCheckedException {
         assert addr != null;
 
         joinLatch = new CountDownLatch(1);
@@ -740,7 +741,7 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
 
                         msgWrk.addMessage(msg);
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         if (log.isDebugEnabled())
                             U.error(log, "Failed to read message [sock=" + sock0 + ", locNodeId=" + locNodeId +
                                 ", rmtNodeId=" + nodeId + ']', e);
@@ -1059,7 +1060,7 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
                             if (log.isDebugEnabled())
                                 log.debug("Heartbeat message sent [sock=" + sock0 + ", msg=" + msg + ']');
                         }
-                        catch (IOException | GridException e) {
+                        catch (IOException | IgniteCheckedException e) {
                             if (log.isDebugEnabled())
                                 U.error(log, "Failed to send heartbeat message [sock=" + sock0 +
                                     ", msg=" + msg + ']', e);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
----------------------------------------------------------------------
@@ -522,9 +523,9 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
      * @return Remote node ID.
      * @throws IOException In case of I/O error.
-     * @throws GridException In case of other error.
+     * @throws IgniteCheckedException In case of other error.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
index 5377e18..9655389 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
@@ -417,9 +417,9 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
      * @param sock Socket.
      * @param msg Message.
      * @throws IOException If IO failed or write timed out.
      * @throws GridException If marshalling failed.
      */
-    protected void writeToSocket(Socket sock, TcpDiscoveryAbstractMessage msg) throws IOException, GridException {
+    protected void writeToSocket(Socket sock, TcpDiscoveryAbstractMessage msg) throws IOException, IgniteCheckedException {
         writeToSocket(sock, msg, new GridByteArrayOutputStream(8 * 1024)); // 8K.
     }
 
@@ -430,11 +430,11 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
      * @param msg Message.
      * @param bout Byte array output stream.
      * @throws IOException If IO failed or write timed out.
      * @throws GridException If marshalling failed.
      */
     @SuppressWarnings("ThrowFromFinallyBlock")
     protected void writeToSocket(Socket sock, TcpDiscoveryAbstractMessage msg, GridByteArrayOutputStream bout)
-        throws IOException, GridException {
+        throws IOException, IgniteCheckedException {
         assert sock != null;
         assert msg != null;
         assert bout != null;
@@ -523,9 +523,9 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
      * @param timeout Socket timeout for this operation.
      * @return Message.
      * @throws IOException If IO failed or read timed out.
      * @throws GridException If unmarshalling failed.
      */
-    protected <T> T readMessage(Socket sock, @Nullable InputStream in, long timeout) throws IOException, GridException {
+    protected <T> T readMessage(Socket sock, @Nullable InputStream in, long timeout) throws IOException, IgniteCheckedException {
         assert sock != null;
 
         int oldTimeout = sock.getSoTimeout();
@@ -535,7 +535,7 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
 
             return marsh.unmarshal(in == null ? sock.getInputStream() : in, U.gridClassLoader());
         }
-        catch (IOException | GridException e) {
+        catch (IOException | IgniteCheckedException e) {
             if (X.hasCause(e, SocketTimeoutException.class))
                 LT.warn(log, null, "Timed out waiting for message to be read (most probably, the reason is " +
                     "in long GC pauses on remote node. Current timeout: " + timeout + '.');
@@ -984,10 +984,10 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
          * @param sock Socket.
          * @param msg Message.
          * @throws IOException If IO failed.
          * @throws GridException If marshalling failed.
          */
         protected final void writeToSocket(Socket sock, TcpDiscoveryAbstractMessage msg)
-            throws IOException, GridException {
+            throws IOException, IgniteCheckedException {
             bout.reset();
 
             TcpDiscoverySpiAdapter.this.writeToSocket(sock, msg, bout);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/multicast/TcpDiscoveryMulticastIpFinder.java
----------------------------------------------------------------------
@@ -417,9 +417,9 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
      * @param msg Message.
      * @throws IOException If IO failed or write timed out.
-     * @throws GridException If marshalling failed.
+     * @throws IgniteCheckedException If marshalling failed.
      */
@@ -430,11 +430,11 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
      * @param bout Byte array output stream.
      * @throws IOException If IO failed or write timed out.
-     * @throws GridException If marshalling failed.
+     * @throws IgniteCheckedException If marshalling failed.
      */
     @SuppressWarnings("ThrowFromFinallyBlock")
@@ -523,9 +523,9 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
      * @return Message.
      * @throws IOException If IO failed or read timed out.
-     * @throws GridException If unmarshalling failed.
+     * @throws IgniteCheckedException If unmarshalling failed.
      */
@@ -984,10 +984,10 @@ abstract class TcpDiscoverySpiAdapter extends IgniteSpiAdapter implements Discov
          * @param msg Message.
          * @throws IOException If IO failed.
-         * @throws GridException If marshalling failed.
+         * @throws IgniteCheckedException If marshalling failed.
          */
         protected final void writeToSocket(Socket sock, TcpDiscoveryAbstractMessage msg)
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/multicast/TcpDiscoveryMulticastIpFinder.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/multicast/TcpDiscoveryMulticastIpFinder.java
index 2e181b5..b3e1327 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/multicast/TcpDiscoveryMulticastIpFinder.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/multicast/TcpDiscoveryMulticastIpFinder.java
@@ -263,7 +263,7 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
         try {
             locAddrs = U.resolveLocalAddresses(U.resolveLocalHost(locAddr)).get1();
         }
-        catch (IOException | GridException e) {
+        catch (IOException | IgniteCheckedException e) {
             throw new IgniteSpiException("Failed to resolve local addresses [locAddr=" + locAddr + ']', e);
         }
 
@@ -440,7 +440,7 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
                             try {
                                 addrRes = new AddressResponse(data);
                             }
-                            catch (GridException e) {
+                            catch (IgniteCheckedException e) {
                                 LT.warn(log, e, "Failed to deserialize multicast response.");
 
                                 continue;
@@ -529,16 +529,16 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
 
         /**
          * @param addrs Addresses discovery SPI binds to.
          * @throws GridException If marshalling failed.
          */
-        private AddressResponse(Collection<InetSocketAddress> addrs) throws GridException {
+        private AddressResponse(Collection<InetSocketAddress> addrs) throws IgniteCheckedException {
             this.addrs = addrs;
 
             byte[] addrsData = marsh.marshal(addrs);
             data = new byte[U.GG_HEADER.length + addrsData.length];
 
             if (data.length > MAX_DATA_LENGTH)
-                throw new GridException("Too long data packet [size=" + data.length + ", max=" + MAX_DATA_LENGTH + "]");
+                throw new IgniteCheckedException("Too long data packet [size=" + data.length + ", max=" + MAX_DATA_LENGTH + "]");
 
             System.arraycopy(U.GG_HEADER, 0, data, 0, U.GG_HEADER.length);
             System.arraycopy(addrsData, 0, data, 4, addrsData.length);
@@ -546,9 +546,9 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
 
         /**
          * @param data Message data.
          * @throws GridException If unmarshalling failed.
          */
-        private AddressResponse(byte[] data) throws GridException {
+        private AddressResponse(byte[] data) throws IgniteCheckedException {
             assert U.bytesEqual(U.GG_HEADER, 0, data, 0, U.GG_HEADER.length);
 
             this.data = data;
@@ -671,7 +671,7 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
             try {
                 res = new AddressResponse(addrs);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 U.error(log, "Failed to prepare multicast message.", e);
 
                 return;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/sharedfs/TcpDiscoverySharedFsIpFinder.java
----------------------------------------------------------------------
@@ -529,16 +529,16 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
         /**
          * @param addrs Addresses discovery SPI binds to.
-         * @throws GridException If marshalling failed.
+         * @throws IgniteCheckedException If marshalling failed.
          */
@@ -546,9 +546,9 @@ public class TcpDiscoveryMulticastIpFinder extends TcpDiscoveryVmIpFinder {
         /**
          * @param data Message data.
-         * @throws GridException If unmarshalling failed.
+         * @throws IgniteCheckedException If unmarshalling failed.
          */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/failover/FailoverContext.java b/modules/core/src/main/java/org/apache/ignite/spi/failover/FailoverContext.java
index 64c6af7..a83c13f 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/failover/FailoverContext.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/failover/FailoverContext.java
@@ -9,9 +9,9 @@
 
 package org.apache.ignite.spi.failover;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
-import org.gridgain.grid.*;
 
 import java.util.*;
 
@@ -41,7 +41,7 @@ public interface FailoverContext {
      *
      * @param top Topology to pick balanced node from.
      * @return The next balanced node.
      * @throws GridException If anything failed.
      */
-    public ClusterNode getBalancedNode(List<ClusterNode> top) throws GridException;
+    public ClusterNode getBalancedNode(List<ClusterNode> top) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
----------------------------------------------------------------------
@@ -41,7 +41,7 @@ public interface FailoverContext {
      * @param top Topology to pick balanced node from.
      * @return The next balanced node.
-     * @throws GridException If anything failed.
+     * @throws IgniteCheckedException If anything failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/LoadBalancingSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/LoadBalancingSpi.java
index 8307372..c61cfe0 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/LoadBalancingSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/LoadBalancingSpi.java
@@ -9,10 +9,10 @@
 
 package org.apache.ignite.spi.loadbalancing;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 
 import java.util.*;
 
@@ -28,7 +28,7 @@ import java.util.*;
  * <pre name="code" class="java">
  * public class MyFooBarTask extends GridComputeTaskSplitAdapter&lt;Object,Object&gt; {
  *    &#64;Override
- *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws GridException {
+ *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws IgniteCheckedException {
  *        List&lt;MyFooBarJob&gt; jobs = new ArrayList&lt;MyFooBarJob&gt;(gridSize);
  *
  *        for (int i = 0; i &lt; gridSize; i++) {
@@ -54,7 +54,7 @@ import java.util.*;
  *    GridComputeLoadBalancer balancer;
  *
  *    // Map jobs to grid nodes.
- *    public Map&lt;? extends ComputeJob, GridNode&gt; map(List&lt;GridNode&gt; subgrid, String arg) throws GridException {
+ *    public Map&lt;? extends ComputeJob, GridNode&gt; map(List&lt;GridNode&gt; subgrid, String arg) throws IgniteCheckedException {
  *        Map&lt;MyFooBarJob, GridNode&gt; jobs = new HashMap&lt;MyFooBarJob, GridNode&gt;(subgrid.size());
  *
  *        // In more complex cases, you can actually do
@@ -70,7 +70,7 @@ import java.util.*;
  *    }
  *
  *    // Aggregate results into one compound result.
- *    public String reduce(List&lt;GridComputeJobResult&gt; results) throws GridException {
+ *    public String reduce(List&lt;GridComputeJobResult&gt; results) throws IgniteCheckedException {
  *        // For the purpose of this example we simply
  *        // concatenate string representation of every
  *        // job result
@@ -107,8 +107,8 @@ public interface LoadBalancingSpi extends IgniteSpi {
      * @param ses Grid task session for currently executing task.
      * @param top Topology of task nodes from which to pick the best balanced node for given job.
      * @param job Job for which to pick the best balanced node.
      * @throws GridException If failed to get next balanced node.
      * @return Best balanced node for the given job within given task session.
      */
-    public ClusterNode getBalancedNode(ComputeTaskSession ses, List<ClusterNode> top, ComputeJob job) throws GridException;
+    public ClusterNode getBalancedNode(ComputeTaskSession ses, List<ClusterNode> top, ComputeJob job) throws IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/adaptive/AdaptiveLoadBalancingSpi.java
----------------------------------------------------------------------
@@ -107,8 +107,8 @@ public interface LoadBalancingSpi extends IgniteSpi {
      * @param top Topology of task nodes from which to pick the best balanced node for given job.
      * @param job Job for which to pick the best balanced node.
-     * @throws GridException If failed to get next balanced node.
+     * @throws IgniteCheckedException If failed to get next balanced node.
      * @return Best balanced node for the given job within given task session.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/adaptive/AdaptiveLoadBalancingSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/adaptive/AdaptiveLoadBalancingSpi.java
index 281a9af..7969a77 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/adaptive/AdaptiveLoadBalancingSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/loadbalancing/adaptive/AdaptiveLoadBalancingSpi.java
@@ -113,7 +113,7 @@ import static org.apache.ignite.events.IgniteEventType.*;
  * <pre name="code" class="java">
  * public class MyFooBarTask extends GridComputeTaskSplitAdapter&lt;Object, Object&gt; {
  *    &#64;Override
- *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws GridException {
+ *    protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, Object arg) throws IgniteCheckedException {
  *        List&lt;MyFooBarJob&gt; jobs = new ArrayList&lt;MyFooBarJob&gt;(gridSize);
  *
  *        for (int i = 0; i &lt; gridSize; i++) {
@@ -139,7 +139,7 @@ import static org.apache.ignite.events.IgniteEventType.*;
  *    GridComputeLoadBalancer balancer;
  *
  *    // Map jobs to grid nodes.
- *    public Map&lt;? extends ComputeJob, GridNode&gt; map(List&lt;GridNode&gt; subgrid, String arg) throws GridException {
+ *    public Map&lt;? extends ComputeJob, GridNode&gt; map(List&lt;GridNode&gt; subgrid, String arg) throws IgniteCheckedException {
  *        Map&lt;MyFooBarJob, GridNode&gt; jobs = new HashMap&lt;MyFooBarJob, GridNode&gt;(subgrid.size());
  *
  *        // In more complex cases, you can actually do
@@ -153,7 +153,7 @@ import static org.apache.ignite.events.IgniteEventType.*;
  *    }
  *
  *    // Aggregate results into one compound result.
- *    public String reduce(List&lt;GridComputeJobResult&gt; results) throws GridException {
+ *    public String reduce(List&lt;GridComputeJobResult&gt; results) throws IgniteCheckedException {
  *        // For the purpose of this example we simply
  *        // concatenate string representation of every
  *        // job result
@@ -407,7 +407,7 @@ public class AdaptiveLoadBalancingSpi extends IgniteSpiAdapter implements LoadBa
 
     /** {@inheritDoc} */
     @Override public ClusterNode getBalancedNode(ComputeTaskSession ses, List<ClusterNode> top, ComputeJob job)
-    throws GridException {
+    throws IgniteCheckedException {
         A.notNull(ses, "ses");
         A.notNull(top, "top");
         A.notNull(job, "job");
@@ -433,10 +433,10 @@ public class AdaptiveLoadBalancingSpi extends IgniteSpiAdapter implements LoadBa
      * @param top List of all nodes.
      * @param node Node to get load for.
      * @return Node load.
      * @throws GridException If returned load is negative.
      */
     @SuppressWarnings({"TooBroadScope"})
-    private double getLoad(Collection<ClusterNode> top, ClusterNode node) throws GridException {
+    private double getLoad(Collection<ClusterNode> top, ClusterNode node) throws IgniteCheckedException {
         assert !F.isEmpty(top);
 
         int jobsSentSinceLastUpdate = 0;
@@ -455,7 +455,7 @@ public class AdaptiveLoadBalancingSpi extends IgniteSpiAdapter implements LoadBa
         double load = probe.getLoad(node, jobsSentSinceLastUpdate);
 
         if (load < 0)
-            throw new GridException("Failed to obtain non-negative load from adaptive load probe: " + load);
+            throw new IgniteCheckedException("Failed to obtain non-negative load from adaptive load probe: " + load);
 
         return load;
     }
@@ -469,9 +469,9 @@ public class AdaptiveLoadBalancingSpi extends IgniteSpiAdapter implements LoadBa
 
         /**
          * @param top Task topology.
          * @throws GridException If any load was negative.
          */
-        WeightedTopology(List<ClusterNode> top) throws GridException {
+        WeightedTopology(List<ClusterNode> top) throws IgniteCheckedException {
             assert !F.isEmpty(top);
 
             double totalLoad = 0;
@@ -433,10 +433,10 @@ public class AdaptiveLoadBalancingSpi extends IgniteSpiAdapter implements LoadBa
      * @param node Node to get load for.
      * @return Node load.
-     * @throws GridException If returned load is negative.
+     * @throws IgniteCheckedException If returned load is negative.
      */
     @SuppressWarnings({"TooBroadScope"})
@@ -469,9 +469,9 @@ public class AdaptiveLoadBalancingSpi extends IgniteSpiAdapter implements LoadBa
         /**
          * @param top Task topology.
-         * @throws GridException If any load was negative.
+         * @throws IgniteCheckedException If any load was negative.
          */